@@ -26,7 +26,7 @@ from django.db.models import Model, Manager, SET, SET_NULL,\
     ForeignKey, DateTimeField, CharField, TextField, IntegerField
 
 from django.utils.translation import ugettext_lazy as _, get_language
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.contrib.auth import get_user_model
 from django.conf import settings
 
@@ -142,7 +142,7 @@ class EditHistory(Model, SiblingMixin):
     language = CharField(_("Plugin Language"), max_length=8,
                          null=True, choices=settings.LANGUAGES)
 
-    published_in = ForeignKey('PublishHistory',
+    published_in = ForeignKey('PublishHistory', on_delete=SET_NULL,
                               related_name='editings', null=True, blank=True)
 
     objects = EditManager()
