@@ -59,7 +59,8 @@ def generate_content(plugin):
         # If it's not a part of a page
         return
 
-    if not plugin.page or not plugin.page.publisher_is_draft:
+    page = plugin.placeholder.page
+    if not page or not page.publisher_is_draft:
         # If it's a live page, we don't want to know.
         return
 
